@@ -108,7 +108,7 @@ class Login:
         return self.auth0_url_encode(hashlib.sha256(a_verifier.encode()).digest())
 
     def run(self):
-        global received_callback, code, error_message, received_state
+        global received_callback
 
         # from https://auth0.com/docs/flows/add-login-using-the-authorization-code-flow-with-pkce
         # Step1: Create code verifier: Generate a code_verifier that will be sent to Auth0 to request tokens.
@@ -122,7 +122,7 @@ class Login:
         redirect_uri = self.redirect_uri
         #
         # We generate a nonce (state) that is used to protect against attackers invoking the callback
-        base_url = "https://%s.auth0.com/authorize?" % tenant
+        base_url = f"https://{tenant}.auth0.com/authorize?"
         url_parameters = {
             "audience": "qainit",
             "scope": scope,
@@ -159,7 +159,7 @@ class Login:
             sys.exit(1)
 
         # Step4: Request tokens: Exchange your authorization_code and code_verifier for tokens.
-        url = "https://%s.auth0.com/oauth/token" % tenant
+        url = f"https://{tenant}.auth0.com/oauth/token"
         headers = {"Content-Type": "application/json"}
         body = {
             "grant_type": "authorization_code",
